/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.artifactdatabase.objects;

import java.io.Serializable;

import java.util.Collection;

/**
 * <code>OutputMode</code> objects give information possible types of exports
 * for an artifact (e.g. chart, histogram, csv, odv, statistic).
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface OutputMode extends Serializable{

    /**
     * Retrieve the name of an output mode.
     *
     * @return the name.
     */
    public String getName();

    /**
     * Retrieve the mimetype of an output mode.
     *
     * @return the mimetype.
     */
    public String getMimeType();

    /**
     * Retrieve the output parameters available to adjust the output.
     *
     * @return the output parameters.
     */
    public Collection<OutputParameter> getOutputParameters();

    /**
     * Retrieve possible export modes which describe specific output modes
     * (e.g. pdf, svg, image).
     *
     * @param mode The export mode's name.
     * @return the export mode.
     */
    public ExportMode getExportMode(String mode);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
